Learn R Programming

cjar (version 0.2.0)

cja_get_audit_logs_search: Get audit logs search

Description

This function will pull a list of audit logs.

Usage

cja_get_audit_logs_search(body = NULL, debug = FALSE)

Value

A data frame of audit logs and corresponding metadata

Arguments

body

The json string with the search functions included

debug

Set to TRUE if needed to help troubleshoot api call errors

Examples

Run this code
if (FALSE) {
cja_get_audit_logs_search(body = jsonrequest)
}

Run the code above in your browser using DataLab