powered by
This function will pull a list of audit logs.
cja_get_audit_logs_search(body = NULL, debug = FALSE)
A data frame of audit logs and corresponding metadata
The json string with the search functions included
Set to TRUE if needed to help troubleshoot api call errors
if (FALSE) { cja_get_audit_logs_search(body = jsonrequest) }
Run the code above in your browser using DataLab